# Generated by Django 3.1.13 on 2021-10-31 16:59

from django.db import migrations, models


def set_defaults(apps, schema_editor):
    Menu = apps.get_model('viewwork', 'Menu')

    Menu.objects.all().update(hidden=False)


class Migration(migrations.Migration):

    dependencies = [
        ('viewwork', '0003_menu_i18n'),
    ]

    operations = [
        migrations.AddField(
            model_name='menu',
            name='enabled',
            field=models.BooleanField(db_index=True, default=True, verbose_name='Enabled item'),
        ),
        migrations.AddField(
            model_name='menu',
            name='hidden',
            field=models.BooleanField(db_index=True, default=True, verbose_name='Hidden item'),
        ),

        migrations.RunPython(set_defaults, reverse_code=migrations.RunPython.noop)
    ]
