# Generated by Django 3.1.13 on 2021-10-16 20:42

from django.db import migrations
import modeltrans.fields


class Migration(migrations.Migration):

    dependencies = [
        ('viewwork', '0002_auto_20210709_1622'),
    ]

    operations = [
        migrations.AddField(
            model_name='menu',
            name='i18n',
            field=modeltrans.fields.TranslationField(fields=('name',), required_languages=(), virtual_fields=True),
        ),
    ]
